@@ -30,7 +30,6 @@ case "della tariffa arrotondato a":  		$messaggio = "de la tarifa arrodonit a";
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considera el cost percentual com a llit(s) addicional(s)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Procedeix a la inserció del nou suplement"; break;
 case "Caparra":  				$messaggio = "Arres"; break;
-case "La caparra normale per la":  		$messaggio = "Les arres per la"; break;
 case "arrotondata a":  				$messaggio = "arrodonida a"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Inserir o modificar les arres"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "Mirar els preus ja inserits"; break;
@@ -229,7 +228,6 @@ case "La caparra è errata":  			$messaggio = "Les arres són errònies"; break;
 case "è":  					$messaggio = "és"; break;
 case "il":  					$messaggio = "el"; break;
 case "Commissioni":  				$messaggio = "Comissions"; break;
-case "Le commissioni normali sulla":  		$messaggio = "Les comissions normals sobre la"; break;
 case "sono":  					$messaggio = "són"; break;
 case "Tasse":  					$messaggio = "Impostos"; break;
 case "della tariffa":  				$messaggio = "de la tarifa"; break;
@@ -269,7 +267,6 @@ case "opzionale":  				$messaggio = "opcional"; break;
 case "Costi combinati":  			$messaggio = "Costos combinats"; break;
 case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Inserció ràpida d'un suplement nou per"; break;
 case "permanenza minima":  			$messaggio = "estada mínima"; break;
-case "numero di bambini":  			$messaggio = "número de nens"; break;
 case "letto aggiuntivo":  			$messaggio = "llit addicional"; break;
 case "offerta speciale":  			$messaggio = "oferta especial"; break;
 case "inserisci":  				$messaggio = "inserir"; break;
@@ -277,10 +274,8 @@ case "Inserisci il costo aggiuntivo":  		$messaggio = "Inserir el suplement"; br
 case "Numero minimo di giorni":  		$messaggio = "Número mínim de dies"; break;
 case "Applicato alle tariffe":  		$messaggio = "Aplicar a les tarifes"; break;
 case "Periodi in cui viene applicato il costo":	$messaggio = "Períodes als quals s'aplica el cost"; break;
-case "Valore dello sconto per ogni bambino":  	$messaggio = "Valor del descompte per cada nen"; break;
 case "del prezzo di una persona":  		$messaggio = "del preu d'una persona"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "només per tarifes amb preus per persona"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "amb aquest cost s'ha d'incloure el  número de nens i el número de persones sumats"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Import del llit addicional"; break;
 case "Valore dello sconto":  			$messaggio = "Import del descompte"; break;
 case "del prezzo totale":  			$messaggio = "del preu total"; break;
@@ -288,10 +283,20 @@ case "Se la prenotazione ha una durata di":	$messaggio = "Si la reserva te una d
 case "o più giorni":  				$messaggio = "o més dies"; break;
 case "Se":  					$messaggio = "Si"; break;
 case "Se si inseriscono":  			$messaggio = "Si s'insereixen"; break;
+case "a":  					$messaggio = "to"; break;
+case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
+case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
 case "i prezzi della":  			$messaggio = "the prices to"; break;
+case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
 case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
 case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
 case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
+case "della tar.":  				$messaggio = "of rate"; break;
+case "di t.+s.":  				$messaggio = "of r.+d."; break;
+case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
+case "numero di neonati":  			$messaggio = "number of infants"; break;
+case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
+case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
 case "Importa ora":  				$messaggio = "Import now"; break;
 case "Importa sempre":  			$messaggio = "Always import"; break;
 case "cancella":  				$messaggio = "delete"; break;
@@ -304,6 +309,28 @@ case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo per
 case "tutte le tariffe":  			$messaggio = "all rates"; break;
 case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
 case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
+case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
+case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
+case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
+case "modifica":  				$messaggio = "modify"; break;
+case "In modo predefinito importa":  		$messaggio = "By default import"; break;
+case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
+case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
+case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
+case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
+case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
+case "escludi":  				$messaggio = "exclude"; break;
+case "includi solo":  				$messaggio = "include only"; break;
+case "questi tipi":  				$messaggio = "these types"; break;
+case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
+case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
+case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
+case "tariffe con":  				$messaggio = "rates with"; break;
+case "per persona nullo":  			$messaggio = "per person zero"; break;
+case "fisso nullo":  				$messaggio = "fixed zero"; break;
+case "da per persona":  			$messaggio = "from per person"; break;
+case "più fisso":  				$messaggio = "from fixed"; break;
+case "dal fisso":  				$messaggio = "plus fixed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
