@@ -134,6 +134,7 @@ case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "El <b>sobrenom</b
 case "Lingua":  				$messaggio = "Idioma"; break;
 case "La lingua verrà cambiata da":  		$messaggio = "L'idioma canviarà de"; break;
 case "La <b>lingua</b> verrà cancellata":  	$messaggio = "L'<b>idioma</b> serà esborrat"; break;
+case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
 case "Email":  					$messaggio = "Email"; break;
 case "TOTALE":  				$messaggio = "TOTAL"; break;
 case "Documento":  				$messaggio = "Document"; break;
@@ -146,9 +147,27 @@ case "Il campo":  				$messaggio = "The field"; break;
 case "verrà tolto":  				$messaggio = "will be deleted"; break;
 case "verrà modificato":  			$messaggio = "will be modified"; break;
 case "verrà aggiunto":  			$messaggio = "will be added"; break;
+case "scaduta":  				$messaggio = "expired"; break;
+case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
+case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
+case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
+case "NOTA":  					$messaggio = "NOTICE"; break;
+case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
+case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
+case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
+case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
+case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
+case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
+case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
+case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
+case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
