@@ -3,7 +3,7 @@
 switch ($messaggio) {
 
 case "Inserisci una nuova prenotazione":  	$messaggio = "Insereix una reserva nova"; break;
-case "Cliente titolare: cognome":  		$messaggio = "Client titular: cognoms"; break;
+case "Cliente titolare":  			$messaggio = "Client titular"; break;
 case "cognome":  				$messaggio = "Cognoms"; break;
 case "nome":  					$messaggio = "Nom"; break;
 case "Dal":  					$messaggio = "Arribada"; break;
@@ -93,12 +93,21 @@ case "resto commissioni":  			$messaggio = "resta comissions"; break;
 case "% del prezzo totale":  			$messaggio = "% del preu total"; break;
 case "modificata":  				$messaggio = "modificada"; break;
 case "costo aggiuntivo":  			$messaggio = "suplement"; break;
+case "Prenota":  				$messaggio = "Reserve"; break;
 case "TOTALE":  				$messaggio = "TOTAL"; break;
+case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
+case "prezzo tariffa":  			$messaggio = "rate price"; break;
 case "Errore":  				$messaggio = "Error"; break;
 case "per la prenotazione":  			$messaggio = "for reservation"; break;
-case "prezzo tariffa":  			$messaggio = "rate price"; break;
 case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
 case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
+case "valuta":  				$messaggio = "currency"; break;
+case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
+case "da":  					$messaggio = "from"; break;
+case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
+case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
+case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
