@@ -302,7 +302,13 @@ case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "pod
 case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "no podrà veure <b>emails, telèfonos ni fax</b> dels clients"; break;
 case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "podrà veure <b>l'adreça</b> dels clients"; break;
 case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "ja no podrà veure <b>l'adreça</b> dels clients"; break;
+case "e":  					$messaggio = "and"; break;
+case "Privilegi Utenti":  			$messaggio = "Users Privileges"; break;
 case "documento":  				$messaggio = "document"; break;
+case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
+case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
+case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
+case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
 case "verrà avvisato <b>sempre</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "will be <b>always</b> informed before inserting reservations in periods of rule 1 of"; break;
 case "verrà avvisato solo quando inserirà prenotazioni nei periodi delle regole 1 <b>non selezionate</b> del":	$messaggio = "will be informed only when inserting reservations in periods of rule 1 <b>not selected</b> of"; break;
 case "non verrà avvisato <b>mai</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "will <b>never</b> be informed when inserting reservations in periods of rule 1 of"; break;
@@ -312,8 +318,16 @@ case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inser
 case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
 case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>extra costs</b> when inserts new reservations in"; break;
 case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>extra costs</b> when inserts new reservations in"; break;
+case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
+case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
 case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
 case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
+case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
+case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
+case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
+case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
 case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
 case "non potrà inserire l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
 case "potrà inserire la l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
@@ -329,24 +343,69 @@ case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed
 case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
 case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
 case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
-case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
-case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
-case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
-case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
-case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
-case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
-case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
-case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
-case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
-case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
-case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
-case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
 case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
 case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
 case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
+case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
+case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
+case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
+case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
+case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
+case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
+case "senza mostrare il valore":  		$messaggio = "without showing the value"; break;
+case "mostrando il valore":  			$messaggio = "showing the value"; break;
+case "senza mostrare i valori":  		$messaggio = "without showing the values"; break;
+case "mostrando i valori":  			$messaggio = "showing the values"; break;
+case "Possibilità di modificare l'utente che ha inserito":	$messaggio = "Possibility to modify the inserting user"; break;
+case "con tutti gli utenti":  			$messaggio = "with all users"; break;
+case "solo con utenti dei suoi gruppi":  	$messaggio = "only with users from his groups"; break;
+case "mostrando l'utente":  			$messaggio = "showing the user"; break;
+case "senza mostrare l'utente":  		$messaggio = "without showing the user"; break;
+case "potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will be able to modify the <b>user</b> that inserted the reservation in"; break;
+case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will not be able to modify the <b>user</b> that inserted the reservation in"; break;
+case "senza mostrarla":  			$messaggio = "without showing it"; break;
+case "senza mostrarli":  			$messaggio = "without showing them"; break;
+case "Modifica delle tipologie di persone":  	$messaggio = "Modify people types"; break;
+case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "will be able to modify his <b>people types</b>"; break;
+case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "will not be able to modify his <b>people types</b>"; break;
+case "Modifica delle valute":  			$messaggio = "Modify currencies"; break;
+case "potrà modificare le sue <b>valute</b>":  	$messaggio = "will be able to modify his <b>currencies</b>"; break;
+case "non potrà più modificare le sue <b>valute</b>":	$messaggio = "will not be able to modify his <b>currencies</b>"; break;
+case "solo per lui":  				$messaggio = "only for him"; break;
+case "anche per i suoi gruppi":  		$messaggio = "also for his groups"; break;
+case "anche per tutti gli utenti":  		$messaggio = "also for all the users"; break;
+case "e quelle di utenti appartenenti ai suoi gruppi":	$messaggio = "and the ones from users belonging to his groups"; break;
+case "e quelle di tutti gli altri utenti":  	$messaggio = "and the ones from all users"; break;
+case "Cancellare le prenotazioni in modo permanente":	$messaggio = "Delete reservations permanently"; break;
+case "non <b>cancellerà mai in modo permanente</b> le prenotazioni nel":	$messaggio = "will <b>never permanently delete</b> reservations in"; break;
+case "potrà scegliere se <b>cancellare in modo permanente</b> le prenotazioni nel":	$messaggio = "will choose if <b>permanently delete</b> reservations in"; break;
+case "<b>cancellerà sempre in modo permanete</b> le prenotazioni nel":	$messaggio = "will <b>always permanently delete</b> reservations in"; break;
+case "Possibilità di modificare le <i>regole di assegnazione</i>":	$messaggio = "Possibility to modify the <i>assignment rules</i>"; break;
+case "non potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 1</b> in"; break;
+case "potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 1</b> in"; break;
+case "non potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 2 and 3</b> in"; break;
+case "potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 2 and 3</b> in"; break;
+case "assegnazione persone":  			$messaggio = "people assignment"; break;
+case "Creazione e modifica delle pagine per il sito web":	$messaggio = "Create and modify website pages"; break;
+case "Solo con i costi aggiuntivi":  		$messaggio = "only with extra costs"; break;
+case "potrà creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will be able to create and modify <b>website pages</b>"; break;
+case "potrà modificare le <b>pagine per il sito web</b> solo quando crea e modifica i costi aggiuntivi":	$messaggio = "will be able to modify <b>website pages</b> only when creating and modifying extra costs"; break;
+case "non potrà più creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will not be able to create and modify <b>website pages</b>"; break;
+case "solo per tariffe":  			$messaggio = "only for rates"; break;
+case "per entrambi":  				$messaggio = "for both"; break;
+case "Modifica dei documenti in formato HTML":	$messaggio = "Modify documents in HTML format"; break;
+case "potrà modificare i <b>documenti con formato HTML</b>":	$messaggio = "will be able to modify <b>documents with HTML format</b>"; break;
+case "non potrà più modificare i <b>documenti con formato HTML</b>":	$messaggio = "will not be able to modify <b>documents with HTML format</b> anymore"; break;
+case "questo può consentire di portare attacchi di tipo \"Cross Site Scripting\" per rubare le credenziali di altri utenti":	$messaggio = "this could allow to carry out \"Cross Site Scripting\" attacks to steal other users' credentials"; break;
+case "Modifica delle password":  		$messaggio = "Modify passwords"; break;
+case "solo la propria":  			$messaggio = "only his own"; break;
+case "potrà modificare solo la sua <b>password</b>":	$messaggio = "will be able to modify only his own <b>password</b>"; break;
+case "non potrà più modificare le <b>password</b>":	$messaggio = "will not be able to modify <b>passwords</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
