@@ -5,6 +5,7 @@
 # numbers and underscore: NO ACCENTS, NO SPACES
 
 $trad_var['cognome'] = 'apellido';
+$trad_var['cognome2'] = 'surname2';
 $trad_var['nome'] = 'nombre';
 $trad_var['soprannome'] = 'apodo';
 $trad_var['titolo'] = 'titulo';
@@ -21,22 +22,26 @@ $trad_var['via'] = 'calle';
 $trad_var['via2'] = 'calle2';
 $trad_var['numcivico'] = 'numero_calle';
 $trad_var['cap'] = 'codigo_postal';
-$trad_var['documento'] = 'documento';
-$trad_var['tipo_documento'] = 'tipo_documento';
+$trad_var['documento'] = 'document';
+$trad_var['tipo_documento'] = 'document_type';
 $trad_var['citta_documento'] = 'ciudad_documento';
 $trad_var['regione_documento'] = 'region_documento';
 $trad_var['nazione_documento'] = 'nacion_documento';
 $trad_var['scadenza_documento'] = 'expiracion_documento';
-$trad_var['telefono'] = 'telefono';
-$trad_var['telefono2'] = 'telefono2';
-$trad_var['telefono3'] = 'telefono3';
+$trad_var['telefono'] = 'telephone';
+$trad_var['telefono2'] = 'telephone2';
+$trad_var['telefono3'] = 'telephone3';
 $trad_var['fax'] = 'fax';
 $trad_var['email'] = 'email';
+$trad_var['email2'] = 'email2';
+$trad_var['email_certificata'] = 'certified_email';
 $trad_var['codice_fiscale'] = 'codigo_fiscal';
 $trad_var['partita_iva'] = 'num_identificacion_fiscal';
+$trad_var['numero_cliente'] = 'client_number';
 $trad_var['num_persone'] = 'num_personas';
 $trad_var['n_letti_agg'] = 'num_camas_extras';
 $trad_var['num_persone_tot'] = 'num_personas_tot';
+$trad_var['num_persone_tipo'] = 'people_num_type';
 $trad_var['costo_tot'] = 'coste_tot';
 $trad_var['caparra'] = 'fianza';
 $trad_var['resto_caparra'] = 'resto_fianza';
@@ -44,18 +49,30 @@ $trad_var['data_inizio'] = 'fecha_inicial';
 $trad_var['data_fine'] = 'fecha_final';
 $trad_var['num_periodi'] = 'num_periodos';
 $trad_var['orario_entrata_stimato'] = 'horario_entrada_estimativo';
+$trad_var['orario_registrazione_entrata'] = 'checkin_time';
+$trad_var['orario_registrazione_uscita'] = 'checkout_time';
 $trad_var['nome_tariffa'] = 'nombre_tarifa';
 $trad_var['costo_tariffa'] = 'precio_tarifa';
 $trad_var['costo_tariffa_p'] = 'precio_tarifa_p';
 $trad_var['costo_tariffa_giorno_array'] = 'rate_price_of_array_day';
 $trad_var['costo_tariffa_giorno_array_p'] = 'rate_price_of_array_day_p';
 $trad_var['sconto'] = 'descuento';
+$trad_var['valuta_tariffa'] = 'rate_currency';
+$trad_var['tasso_cambio_tariffa'] = 'rate_exchange_rate';
+$trad_var['costo_valuta_tariffa'] = 'rate_currency_price';
+$trad_var['costo_valuta_tot'] = 'price_currency_tot';
+$trad_var['valore_valuta_sconto'] = 'discount_currency_value';
+$trad_var['valuta_caparra'] = 'deposit_currency';
+$trad_var['valore_valuta_caparra'] = 'deposit_currency_value';
+$trad_var['tasso_cambio_caparra'] = 'deposit_exchange_rate';
+$trad_var['metodo_pagamento_caparra'] = 'deposit_payment_method';
 $trad_var['commento'] = 'comentario';
 $trad_var['promemoria_entrata'] = 'checkin_reminder';
 $trad_var['promemoria_uscita'] = 'checkout_reminder';
 $trad_var['origine_prenotazione'] = 'origen_reserva';
 $trad_var['unita_occupata'] = 'unidad_ocupada';
 $trad_var['unita_assegnabili'] = 'lista_unidades';
+$trad_var['conferma'] = 'confirmation';
 $trad_var['pagato'] = 'pagado';
 $trad_var['pagato_p'] = 'pagado_p';
 $trad_var['resto_da_pagare'] = 'resto_a_pagar';
@@ -76,6 +93,7 @@ $trad_var['sconto_senza_tasse_p'] = 'descuento_sin_tasas_p';
 $trad_var['nome_costo_agg'] = 'nombre_coste_agna';
 $trad_var['valore_costo_agg'] = 'valor_coste_agna';
 $trad_var['valore_costo_agg_p'] = 'valor_coste_agna_p';
+$trad_var['giorni_costo_agg'] = 'extra_cost_days';
 $trad_var['valore_tutti_costi_agg'] = 'valor_todos_costes_agnadidos';
 $trad_var['valore_tutti_costi_agg_p'] = 'valor_todos_costes_agnadidos_p';
 $trad_var['tutti_i_costi_agg'] = 'todos_costes_agnadidos';
@@ -94,6 +112,11 @@ $trad_var['valore_costo_agg_senza_tasse'] = 'valor_coste_agna_sin_tasas';
 $trad_var['valore_costo_agg_senza_tasse_p'] = 'valor_coste_agna_sin_tasas_p';
 $trad_var['moltiplica_max_costo_agg'] = 'extra_cost_max_multiply';
 $trad_var['moltiplica_max_costo_agg_sel'] = 'sel_extra_cost_max_multiply';
+$trad_var['valore_giornaliero_max_costo_agg'] = 'extra_cost_max_daily_value';
+$trad_var['valore_giornaliero_max_costo_agg_p'] = 'extra_cost_max_daily_value_p';
+$trad_var['valore_giornaliero_max_costo_agg_sel'] = 'sel_extra_cost_max_daily_value';
+$trad_var['valore_giornaliero_max_costo_agg_sel_p'] = 'sel_extra_cost_max_daily_value_p';
+$trad_var['tipo_persona_costo_agg'] = 'extra_cost_person_type';
 $trad_var['data_inserimento_costo_agg'] = 'extra_cost_insertion_date';
 $trad_var['utente_inserimento_costo_agg'] = 'extra_cost_insertion_user';
 $trad_var['percentuale_tasse_costo_agg_sel'] = 'porcentage_tasas_coste_agna_sel';
@@ -103,11 +126,18 @@ $trad_var['sconto_p'] = 'descuento_p';
 $trad_var['num_costi_aggiuntivi'] = 'num_costes_agnadidos';
 $trad_var['valore_pagamento'] = 'payment_value';
 $trad_var['valore_pagamento_p'] = 'payment_value_p';
+$trad_var['valuta_pagamento'] = 'payment_currency';
+$trad_var['valore_valuta_pagamento'] = 'payment_currency_value';
+$trad_var['tasso_cambio_pagamento'] = 'payment_exchange_rate';
 $trad_var['data_pagamento'] = 'payment_date';
 $trad_var['utente_pagamento'] = 'payment_user';
 $trad_var['metodo_pagamento'] = 'payment_method';
+$trad_var['id_pagamento'] = 'payment_id';
+$trad_var['note_pagamento'] = 'payment_notes';
+$trad_var['data_operazione_pagamento'] = 'payment_transaction_date';
 $trad_var['tutti_i_pagamenti'] = 'todos_los_pagos';
 $trad_var['tutti_i_pagamenti_p'] = 'todos_los_pagos_p';
+$trad_var['ultimo_pagamento'] = 'last_payment';
 $trad_var['valore_ultimo_pagamento'] = 'valor_ultimo_pago';
 $trad_var['valore_ultimo_pagamento_p'] = 'valor_ultimo_pago_p';
 $trad_var['data_ultimo_pagamento'] = 'fecha_ultimo_pago';
@@ -117,6 +147,7 @@ $trad_var['num_pagamenti'] = 'num_pagos';
 $trad_var['numero_prenotazione'] = 'numero_reserva';
 $trad_var['numero_ripetizione_prenotazioni'] = 'numero_repeticion_reservas';
 $trad_var['codice_prenotazione'] = 'codigo_reserva';
+$trad_var['ultima_prenotazione_per_cliente'] = 'last_reservation_for_client';
 $trad_var['data_inserimento_prenotazione'] = 'fecha_insercion_reserva';
 $trad_var['utente_inserimento_prenotazione'] = 'reservation_insertion_user';
 $trad_var['numero_progressivo_documento'] = 'numero_progresivo_documento';
@@ -157,7 +188,9 @@ $trad_var['codice3_regione_documento'] = 'codigo3_region_documento';
 $trad_var['codice3_nazione_documento'] = 'codigo3_nacion_documento';
 $trad_var['num_ospiti_tot'] = 'num_huespedes_tot';
 $trad_var['numero_ospite'] = 'numero_huesped';
+$trad_var['numero_cliente_ospite'] = 'client_number_guest';
 $trad_var['cognome_ospite'] = 'apellido_huesped';
+$trad_var['cognome2_ospite'] = 'surname2_guest';
 $trad_var['nome_ospite'] = 'nombre_huesped';
 $trad_var['soprannome_ospite'] = 'apodo_huesped';
 $trad_var['titolo_ospite'] = 'titulo_huesped';
@@ -186,6 +219,8 @@ $trad_var['telefono2_ospite'] = 'telefono2_huesped';
 $trad_var['telefono3_ospite'] = 'telefono3_huesped';
 $trad_var['fax_ospite'] = 'fax_huesped';
 $trad_var['email_ospite'] = 'email_huesped';
+$trad_var['email2_ospite'] = 'email2_guest';
+$trad_var['email_certificata_ospite'] = 'certified_email_guest';
 $trad_var['codice_fiscale_ospite'] = 'codigo_fiscal_huesped';
 $trad_var['partita_iva_ospite'] = 'num_identificacion_fiscal_huesped';
 $trad_var['codice_cittadinanza_ospite'] = 'codigo_nacionalidad_huesped';
@@ -230,6 +265,9 @@ $trad_var['piano_unita'] = 'unit_floor';
 $trad_var['capacita_unita'] = 'unit_capacity';
 $trad_var['priorita_unita'] = 'unit_priority';
 $trad_var['num_unita'] = 'units_num';
+$trad_var['lista_inventario_unita'] = 'units_inventory_list';
+$trad_var['mancanti_inventario_unita'] = 'units_inventory_missing';
+$trad_var['dettagli_inventario_unita'] = 'units_inventory_details';
 $trad_var['costo_tot_somma_ripetizioni'] = 'coste_tot_suma_repeticiones';
 $trad_var['costo_tot_somma_ripetizioni_p'] = 'coste_tot_suma_repeticiones_p';
 $trad_var['caparra_somma_ripetizioni'] = 'fianza_suma_repeticiones';
@@ -243,6 +281,7 @@ $trad_var['resto_da_pagare_somma_ripetizioni_p'] = 'resto_a_pagar_suma_repeticio
 $trad_var['num_persone_tot_somma_ripetizioni'] = 'num_personas_tot_suma_repeticiones';
 $trad_var['data_inizio_selezione'] = 'fecha_inicial_seleccion';
 $trad_var['data_fine_selezione'] = 'fecha_final_seleccion';
+$trad_var['numero_prenotazioni_selezione'] = 'selection_reservations_number';
 $trad_var['utente_attuale'] = 'current_user';
 $trad_var['nome_struttura'] = 'nombre_estructura';
 $trad_var['tipo_struttura'] = 'tipo_estructura';
@@ -251,6 +290,7 @@ $trad_var['ragione_sociale_struttura'] = 'razon_social_estructura';
 $trad_var['sito_web_struttura'] = 'sitio_web_estructura';
 $trad_var['nome_contatto_struttura'] = 'nombre_contacto_estructura';
 $trad_var['nazione_struttura'] = 'nacion_estructura';
+$trad_var['regione_struttura'] = 'structure_region';
 $trad_var['comune_struttura'] = 'ciudad_estructura';
 $trad_var['indirizzo_struttura'] = 'direccion_estructura';
 $trad_var['CAP_struttura'] = 'codigo_postal_estructura';
@@ -260,17 +300,35 @@ $trad_var['codice_fiscale_struttura'] = 'codigo_fiscal_estructura';
 $trad_var['partita_iva_struttura'] = 'num_identificacion_fiscal_estructura';
 $trad_var['numero_stelle_struttura'] = 'numero_estrellas_estructura';
 $trad_var['logo_struttura'] = 'structure_logo';
+$trad_var['codice_nazione_struttura'] = 'structure_nation_code';
+$trad_var['codice_regione_struttura'] = 'structure_region_code';
+$trad_var['codice_comune_struttura'] = 'structure_city_code';
+$trad_var['codice2_nazione_struttura'] = 'structure_nation_code2';
+$trad_var['codice2_regione_struttura'] = 'structure_region_code2';
+$trad_var['codice2_comune_struttura'] = 'structure_city_code2';
+$trad_var['codice3_nazione_struttura'] = 'structure_nation_code3';
+$trad_var['codice3_regione_struttura'] = 'structure_region_code3';
+$trad_var['codice3_comune_struttura'] = 'structure_city_code3';
+$trad_var['nome_valuta'] = 'nombre_divisa';
 $trad_var['testo_email_richiesta'] = 'enquiry_email_text';
 $trad_var['testo_quotato_email_richiesta'] = 'enquiry_email_quoted_text';
-$trad_var['nome_valuta'] = 'nombre_divisa';
+$trad_var['url_base_pagine_web'] = 'base_url_for_webpages';
 $trad_var['ritorno_a_capo'] = 'carriage_return';
 $trad_var['avanzamento_riga'] = 'new_line';
+$trad_var['valore_nullo'] = 'null_value';
 $trad_var['errore_ripetizione'] = 'error_repeticion';
 $trad_var['messaggio_di_errore'] = 'mensaje_de_error';
 $trad_var['codice_lingua'] = 'codigo_idioma';
 $trad_var['email_gia_inviata'] = 'email_already_sent';
 $trad_var['commento_personalizzato'] = 'custom_comment';
 $trad_var['campo_personalizzato'] = 'custom_field';
+$trad_var['nome_documento_salvato'] = 'saved_document_name';
+$trad_var['numero_progressivo_documento_salvato'] = 'saved_document_progressive_number';
+$trad_var['data_creazione_documento_salvato'] = 'saved_document_creation_date';
+$trad_var['nome_file_documento_salvato'] = 'saved_document_filename';
+$trad_var['nome_download_documento_salvato'] = 'saved_document_download_name';
+$trad_var['nome_documento_scaricato'] = 'downloaded_document_name';
+$trad_var['allegato'] = 'attachment';
 
 
 ?>
\ No newline at end of file
